@@ -17,7 +17,7 @@ def _gen_id():
 class RateLimitRuleOrm(PluginModel, table=True):
     __tablename__ = 'nonebot_plugin_access_control_rate_limit_rule'
     __table_args__ = (
-        Index("ix_subject_service", "subject", "service"),
+        Index("ix_nonebot_plugin_access_control_rate_limit_rule_subject_service", "subject", "service"),
         {
             "extend_existing": True
         }
